summaryrefslogtreecommitdiff
path: root/include/Message
diff options
context:
space:
mode:
authorYanis002 <35189056+Yanis002@users.noreply.github.com>2025-02-05 01:47:40 +0100
committerYanis002 <35189056+Yanis002@users.noreply.github.com>2025-02-05 01:47:40 +0100
commit5bd0f31b8bb36f54578a109a6dc6a24a2d6e4631 (patch)
tree3fe0cf67868cca32199cd47e3cc2ecf7cd4df5ef /include/Message
parent7173439cd8424b562b3bc87b935e29aaaf14658e (diff)
post-update cleanup: step 3 (1/2)
Diffstat (limited to 'include/Message')
-rw-r--r--include/Message/BMG.hpp2
-rw-r--r--include/Message/MessageManager.hpp16
-rw-r--r--include/Message/MsgProc.hpp20
3 files changed, 19 insertions, 19 deletions
diff --git a/include/Message/BMG.hpp b/include/Message/BMG.hpp
index 0b13b47f..53a418ea 100644
--- a/include/Message/BMG.hpp
+++ b/include/Message/BMG.hpp
@@ -169,7 +169,7 @@ typedef struct BMGFileInfo {
/* 0x08 */ SectionFLW1* pFLW1; // pointer to the message flow data (FLW -> flow)
/* 0x0C */ SectionFLI1* pFLI1; // pointer to the message flow index table (FLI -> flow index table)
/* 0x10 */ SectionDAT1* pDAT1; // pointer to the data (DAT -> data)
- /* 0x14 */ BMGHeader* mUnk_14; // same as unk_00 (?)
+ /* 0x14 */ BMGHeader* mUnk_14; // same as pHeader (?)
/* 0x18 */ s16 mUnk_18; // stores `func_020372f0`->param_3 value (currently undetermined purpose)
/* 0x1A */ s16 groupId; // stores the group id
} BMGFileInfo; // size = 0x1C
diff --git a/include/Message/MsgProc.hpp b/include/Message/MsgProc.hpp
index 204f26c0..2874fd99 100644
--- a/include/Message/MsgProc.hpp
+++ b/include/Message/MsgProc.hpp
@@ -24,9 +24,9 @@ typedef struct UnkStruct_0203b264 {
/* 8 */
} UnkStruct_0203b264;
-class UnkSubClass1_unk_410 {
+class UnkStruct_020397f8_410 {
public:
- /* 0x00 */ struct MsgProc_Type1* mUnk_00;
+ /* 0x00 */ struct UnkStruct_020397f8* mUnk_00;
/* 0x04 */
void func_0203ec34(void);
@@ -35,10 +35,10 @@ public:
void func_0203ec4c(UnkStruct_0203b264* param_2, unk32 param_3, s32 param_4, s32 param_5);
};
-// same as UnkSubClass1_unk_410?
-class UnkSubClass1_unk_424 {
+// same as UnkStruct_020397f8_410?
+class UnkStruct_020397f8_424 {
public:
- /* 0x00 */ struct MsgProc_Type1* mUnk_00;
+ /* 0x00 */ struct UnkStruct_020397f8* mUnk_00;
/* 0x04 */
void func_0203ee80(unk32);
@@ -48,19 +48,19 @@ public:
UnkStruct_0203b264* func_0203eeb0(unk32 param_2, unk32 param_3);
};
-class MsgProc_Base2_unk_114 : public SysObject {
+class UnkStruct_0203dae0_114 : public SysObject {
public:
/* 0x00 (vtable) */
/* 0x04 */ unk32* mUnk_04;
/* 0x08 */
- MsgProc_Base2_unk_114();
- /* 0x00 */ virtual ~MsgProc_Base2_unk_114() override;
+ UnkStruct_0203dae0_114();
+ /* 0x00 */ virtual ~UnkStruct_0203dae0_114() override;
/* 0x04 */ virtual UNK_TYPE vfunc_04(UNK_TYPE);
/* 0x08 */ virtual unk32 vfunc_08(void*, s16);
/* 0x0C */
- unk32 func_0203d1b4(void);
+ unk32* func_0203d1b4(void);
};
struct func_02038f44_param4 {
@@ -80,7 +80,7 @@ struct func_02038f44_param4 {
extern "C" u32 func_01ff9b4c(unk32, unk32);
extern "C" unk32 func_0203c084(void);
-extern "C" void func_ov018_02169634(MsgProc_Type1*);
+extern "C" void func_ov018_02169634(UnkStruct_020397f8*);
extern "C" unk32 func_ov000_02079e04(void);
extern "C" unk32 func_02016fcc(unk32);
extern "C" void func_02032304(unk32*, char*, unk32, unk32, unk32);
diff --git a/include/Message/MessageManager.hpp b/include/Message/MessageManager.hpp
index c408caf7..17d8e0b2 100644
--- a/include/Message/MessageManager.hpp
+++ b/include/Message/MessageManager.hpp
@@ -17,17 +17,17 @@ public:
/* 0x04 */ u8 mUnk_04;
/* 0x05 */ u8 mUnk_05;
/* 0x06 */ unk16 mUnk_06;
- /* 0x08 */ MsgProc_Type1* mUnk_08;
+ /* 0x08 */ UnkStruct_020397f8* mUnk_08;
/* 0x0C */ u8 mUnk_0c;
/* 0x0C */ u8 mUnk_0d;
/* 0x0C */ unk16 mUnk_0e;
/* 0x10 */ unk16 mUnk_10;
/* 0x10 */ unk16 mUnk_12;
/* 0x14 */ BMGGroups* pGroups;
/* 0x18 */ UnkStruct_020386d8* unk_18[2];
/* 0x20 */ UnkStruct_02037750* unk_20[2];
/* 0x28 */ UnkStruct_02038aa0* unk_28[6];
/* 0x40 */ MsgProc_Type1* unk_40[2]; // is array size 6?
/* 0x48 */
static void func_0203643c(int *param_1, UnkStruct_027E0C68* param_2, u32 param_3);
@@ -35,8 +35,8 @@ public:
void func_0203665c(void);
UnkStruct_027E0C68();
~UnkStruct_027E0C68();
- MsgProc_Type1* func_020366c4(void);
- MsgProc_Type1* func_02036700(void);
+ UnkStruct_020397f8* func_020366c4(void);
+ UnkStruct_020397f8* func_02036700(void);
UnkStruct_020386d8* func_0203673c(void);
bool func_02036770(u32 param_2);
unk32 func_02036798(void);
@@ -57,7 +57,7 @@ public:
void func_02036d6c(void);
UnkStruct_02038aa0* func_02036da8(u32 param_2, s16* param_3);
void func_02036edc(u32 param_2, u8 param_3);
- MsgProc_Type1* func_02036f68(u32 param_2, u8* param_3);
+ UnkStruct_020397f8* func_02036f68(u32 param_2, u8* param_3);
UnkStruct_020386d8* func_020370d0(unk32 param_2, unk32 param_3);
UnkStruct_020386d8* func_020370e8(unk32 param_2, unk16 param_3, unk16 param_4, unk32 param_5);
void func_02037158(UnkSubClass1_02256FF8* param_2);
@@ -17,17 +17,17 @@ public:
/* 0x10 */ unk16 mUnk_12;
/* 0x14 */ BMGGroups* pGroups;
- /* 0x18 */ UnkStruct_020386d8* unk_18[2];
- /* 0x20 */ UnkStruct_02037750* unk_20[2];
- /* 0x28 */ UnkStruct_02038aa0* unk_28[6];
- /* 0x40 */ MsgProc_Type1* unk_40[2]; // is array size 6?
+ /* 0x18 */ UnkStruct_020386d8* mUnk_18[2];
+ /* 0x20 */ UnkStruct_02037750* mUnk_20[2];
+ /* 0x28 */ UnkStruct_02038aa0* mUnk_28[6];
+ /* 0x40 */ UnkStruct_020397f8* mUnk_40[2]; // is array size 6?
/* 0x48 */
static void func_0203643c(int *param_1, UnkStruct_027E0C68* param_2, u32 param_3);